<?php

namespace Litepie\Media\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Litepie\Media\Interfaces\GroupRepositoryInterface;

class GroupPublicController extends BaseController
{
    // use GroupWorkflow;

    /**
     * Constructor.
     *
     * @param type \Litepie\Group\Interfaces\GroupRepositoryInterface $group
     *
     * @return type
     */
    public function __construct(GroupRepositoryInterface $group)
    {
        $this->repository = $group;
        parent::__construct();
    }

    /**
     * Show group's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $groups = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->setMetaTitle(trans('media::group.names'))
            ->view('media::public.group.index')
            ->data(compact('groups'))
            ->output();
    }


    /**
     * Show group.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $group = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->setMetaTitle($group->name . trans('media::group.name'))
            ->view('media::public.group.show')
            ->data(compact('group'))
            ->output();
    }

}
