<?php

namespace Litepie\Media\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Litepie\Media\Http\Requests\MediaRequest;
use Litepie\Media\Interfaces\MediaRepositoryInterface;
use Litepie\Media\Models\Media;
use Litepie\Media\Forms\Media as Form;

/**
 * APIController  class for media.
 */
class MediaAPIController extends BaseController
{

    /**
     * Initialize media resource controller.
     *
     * @param type MediaRepositoryInterface $media
     *
     * @return null
     */
    public function __construct(MediaRepositoryInterface $media)
    {
        parent::__construct();
        $this->repository = $media;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litepie\Media\Repositories\Criteria\MediaResourceCriteria::class);
    }

    /**
     * Display a list of media.
     *
     * @return Response
     */
    public function index(MediaRequest $request)
    {
        return $this->repository
            ->setPresenter(\Litepie\Media\Repositories\Presenter\MediaPresenter::class)
            ->paginate();
    }

    /**
     * Display media.
     *
     * @param Request $request
     * @param Model   $media
     *
     * @return Response
     */
    public function show(MediaRequest $request, Media $media)
    {
        return $media->setPresenter(\Litepie\Media\Repositories\Presenter\MediaListPresenter::class);
        ;
    }

    /**
     * Create new media.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(MediaRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('media::media.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('media/media/' . $media->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('media/media');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the media.
     *
     * @param Request $request
     * @param Model   $media
     *
     * @return Response
     */
    public function update(MediaRequest $request, Media $media)
    {
        try {
            $data = $request->all();

            $media->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('media::media.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('media/media/' . $media->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('media/media/' . $media->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the media.
     *
     * @param Model   $media
     *
     * @return Response
     */
    public function destroy(MediaRequest $request, Media $media)
    {
        try {
            $media->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('media::media.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('media/media/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('media/media/' . $media->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
