<?php

namespace Litepie\Media\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Litepie\Media\Interfaces\MediaRepositoryInterface;

class MediaPublicController extends BaseController
{
    // use MediaWorkflow;

    /**
     * Constructor.
     *
     * @param type \Litepie\Media\Interfaces\MediaRepositoryInterface $media
     *
     * @return type
     */
    public function __construct(MediaRepositoryInterface $media)
    {
        $this->repository = $media;
        parent::__construct();
    }

    /**
     * Show media's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $media = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->setMetaTitle(trans('media::media.names'))
            ->view('media::public.media.index')
            ->data(compact('media'))
            ->output();
    }


    /**
     * Show media.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $media = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->setMetaTitle($media->name . trans('media::media.name'))
            ->view('media::public.media.show')
            ->data(compact('media'))
            ->output();
    }

}
