<?php

namespace Litepie\Media\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litepie\Media\Models\Group;

class GroupPolicy
{

    /**
     * Determine if the given user can view the group.
     *
     * @param UserPolicy $user
     * @param Group $group
     *
     * @return bool
     */
    public function view(UserPolicy $user, Group $group)
    {
        if ($user->canDo('media.group.view') && $user->isAdmin()) {
            return true;
        }

        return $group->user_id == user_id() && $group->user_type == user_type();
    }

    /**
     * Determine if the given user can create a group.
     *
     * @param UserPolicy $user
     * @param Group $group
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('media.group.create');
    }

    /**
     * Determine if the given user can update the given group.
     *
     * @param UserPolicy $user
     * @param Group $group
     *
     * @return bool
     */
    public function update(UserPolicy $user, Group $group)
    {
        if ($user->canDo('media.group.edit') && $user->isAdmin()) {
            return true;
        }

        return $group->user_id == user_id() && $group->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given group.
     *
     * @param UserPolicy $user
     * @param Group $group
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Group $group)
    {
        return $group->user_id == user_id() && $group->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given group.
     *
     * @param UserPolicy $user
     * @param Group $group
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Group $group)
    {
        if ($user->canDo('media.group.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given group.
     *
     * @param UserPolicy $user
     * @param Group $group
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Group $group)
    {
        if ($user->canDo('media.group.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
