<?php

namespace Litepie\Media\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litepie\Media\Models\Media;

class MediaPolicy
{

    /**
     * Determine if the given user can view the media.
     *
     * @param UserPolicy $user
     * @param Media $media
     *
     * @return bool
     */
    public function view(UserPolicy $user, Media $media)
    {
        if ($user->canDo('media.media.view') && $user->isAdmin()) {
            return true;
        }

        return $media->user_id == user_id() && $media->user_type == user_type();
    }

    /**
     * Determine if the given user can create a media.
     *
     * @param UserPolicy $user
     * @param Media $media
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('media.media.create');
    }

    /**
     * Determine if the given user can update the given media.
     *
     * @param UserPolicy $user
     * @param Media $media
     *
     * @return bool
     */
    public function update(UserPolicy $user, Media $media)
    {
        if ($user->canDo('media.media.edit') && $user->isAdmin()) {
            return true;
        }

        return $media->user_id == user_id() && $media->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given media.
     *
     * @param UserPolicy $user
     * @param Media $media
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Media $media)
    {
        return $media->user_id == user_id() && $media->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given media.
     *
     * @param UserPolicy $user
     * @param Media $media
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Media $media)
    {
        if ($user->canDo('media.media.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given media.
     *
     * @param UserPolicy $user
     * @param Media $media
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Media $media)
    {
        if ($user->canDo('media.media.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
