<?php

namespace Litepie\Media\Providers;

use Illuminate\Support\ServiceProvider;

class MediaServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'media');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'media');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerMedia();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerMedia()
    {
        $this->app->bind('media', function($app) {
            return new Media($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Media', 'Lavalite\Media\Facades\Media');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('litepie.media', function ($app) {
            return $this->app->make('Litepie\Media\Media');
        });

        // Bind Group to repository
        $this->app->bind(
            'Litepie\Media\Interfaces\GroupRepositoryInterface',
            \Litepie\Media\Repositories\Eloquent\GroupRepository::class
        );
        // Bind Contact to repository
        $this->app->bind(
            'Litepie\Media\Interfaces\ContactRepositoryInterface',
            \Litepie\Media\Repositories\Eloquent\ContactRepository::class
        );
        // Bind Media to repository
        $this->app->bind(
            'Litepie\Media\Interfaces\MediaRepositoryInterface',
            \Litepie\Media\Repositories\Eloquent\MediaRepository::class
        );
        // Bind Variant to repository
        $this->app->bind(
            'Litepie\Media\Interfaces\VariantRepositoryInterface',
            \Litepie\Media\Repositories\Eloquent\VariantRepository::class
        );

        $this->app->register(\Litepie\Media\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Litepie\Media\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and media's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'litepie.media'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeMedia::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litepie.media'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litepie/media.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/media')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/media')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
