<?php

namespace Litepie\Media\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Routing\Router;
use Litepie\Media\Models\Media;
use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Litepie\Media\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/media/group/*')) {
            Route::bind('group', function ($group) {
                $grouprepo = $this->app->make('Litepie\Media\Interfaces\GroupRepositoryInterface');
                return $grouprepo->findorNew($group);
            });
        }

        if (Request::is('*/media/contact/*')) {
            Route::bind('contact', function ($contact) {
                $contactrepo = $this->app->make('Litepie\Media\Interfaces\ContactRepositoryInterface');
                return $contactrepo->findorNew($contact);
            });
        }

        if (Request::is('*/media/media/*')) {
            Route::bind('media', function ($media) {
                $mediarepo = $this->app->make('Litepie\Media\Interfaces\MediaRepositoryInterface');
                return $mediarepo->findorNew($media);
            });
        }

        if (Request::is('*/media/variant/*')) {
            Route::bind('variant', function ($variant) {
                $variantrepo = $this->app->make('Litepie\Media\Interfaces\VariantRepositoryInterface');
                return $variantrepo->findorNew($variant);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {   
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

}
